#
# spec file for package python-certbot
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-certbot
Version:        0.36.0
Release:        lp151.2.3.1
Summary:        ACME client
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://github.com/certbot/certbot
Source:         https://files.pythonhosted.org/packages/source/c/certbot/certbot-%{version}.tar.gz
BuildRequires:  %{python_module acme >= 0.29.0}
BuildRequires:  %{python_module configargparse >= 0.9.3}
BuildRequires:  %{python_module configobj}
BuildRequires:  %{python_module cryptography >= 1.2.3}
BuildRequires:  %{python_module future}
BuildRequires:  %{python_module josepy >= 1.1.0}
BuildRequires:  %{python_module mock}
BuildRequires:  %{python_module parsedatetime >= 1.3}
BuildRequires:  %{python_module pyRFC3339}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module pytz}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module zope.component}
BuildRequires:  %{python_module zope.interface}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  python2-typing
Requires:       python-acme >= 0.29.0
Requires:       python-configargparse >= 0.9.3
Requires:       python-configobj
Requires:       python-cryptography >= 1.2.3
Requires:       python-future
Requires:       python-josepy >= 1.1.0
Requires:       python-mock
Requires:       python-parsedatetime >= 1.3
Requires:       python-pyRFC3339
Requires:       python-pytz
Requires:       python-setuptools
Requires:       python-zope.component
Requires:       python-zope.interface
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
%ifpython2
Requires:       python-typing
%endif
Provides:       certbot = %{version}
Obsoletes:      certbot < %{version}
%python_subpackages

%description
certbot is a free, automated certificate authority that aims
to lower the barriers to entry for encrypting all HTTP traffic on the internet.

%prep
%setup -q -n certbot-%{version}

%build
%python_build

%install
%python_install
%python_clone -a %{buildroot}%{_bindir}/certbot
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%post
%python_install_alternative certbot
# migrate from old certbot to new certbot
if test ! -h %{_sysconfdir}/certbot -a -e %{_sysconfdir}/certbot; then
	echo "Migrating %{_sysconfdir}/certbot to %{_sysconfdir}/letsencrypt..."
	mv %{_sysconfdir}/letsencrypt %{_sysconfdir}/letsencrypt.empty
	mv %{_sysconfdir}/certbot %{_sysconfdir}/letsencrypt
	cd %{_sysconfdir} ; ln -s letsencrypt certbot
fi

%postun
%python_uninstall_alternative certbot

%files %{python_files}
%license LICENSE.txt
%doc README.rst
%{python_sitelib}/*
%python_alternative %{_bindir}/certbot

%changelog
* Wed Jul 24 2019 Robert Frohl <rfrohl@suse.com>
- Updated Provides and Obsoletes on certbot to include the python2-certbot package
* Wed Jul 17 2019 Marketa Calabkova <mcalabkova@suse.com>
- update to version 0.36.0 (bsc#1141928)
  * Update the 'manage your account' help to be more generic.
  * Certbot's config_changes subcommand has been deprecated and
    will be removed in a future release.
  * certbot config_changes no longer accepts a --num parameter.
  * The functions certbot.plugins.common.Installer.view_config_changes
    and certbot.reverter.Reverter.view_config_changes have been
    deprecated and will be removed in a future release.
* Tue Jun 18 2019 Marketa Calabkova <mcalabkova@suse.com>
- update to 0.35.1
  * Renewal parameter webroot_path is always saved.
  * Scripts in Certbot hook directories are no longer executed when
    their filenames end in a tilde.
* Sat May 18 2019 Dirk Mueller <dmueller@suse.com>
- update to 0.34.2:
  * Apache plugin now tries to restart httpd on Fedora using systemctl if a
    configuration test error is detected. This has to be done due to the way
    Fedora now generates the self signed certificate files upon first
    restart.
  * Updated Certbot and its plugins to improve the handling of file system permissions
    on Windows as a step towards adding proper Windows support to Certbot.
  * Updated urllib3 to 1.24.2 in certbot-auto.
  * Removed the fallback introduced with 0.32.0 in `acme` to retry a challenge response
    with a `keyAuthorization` if sending the response without this field caused a
    `malformed` error to be received from the ACME server.
  * Linode DNS plugin now supports api keys created from their new panel
    at [cloud.linode.com](https://cloud.linode.com)
  * Adding a warning noting that future versions of Certbot will automatically configure the
    webserver so that all requests redirect to secure HTTPS access. You can control this
    behavior and disable this warning with the --redirect and --no-redirect flags.
  * certbot-auto now prints warnings when run as root with insecure file system
    permissions. If you see these messages, you should fix the problem by
    following the instructions at
    https://community.letsencrypt.org/t/certbot-auto-deployment-best-practices/91979/,
    however, these warnings can be disabled as necessary with the flag
  - -no-permissions-check.
  * `acme` module uses now a POST-as-GET request to retrieve the registration
    from an ACME v2 server
  * Convert the tsig algorithm specified in the certbot_dns_rfc2136 configuration file to
    all uppercase letters before validating. This makes the value in the config case
    insensitive.
* Fri May  3 2019 Marketa Calabkova <mcalabkova@suse.com>
- Add migration script from old certbot to the new one (boo#1119619).
* Mon Mar 18 2019 Marketa Calabkova <mcalabkova@suse.com>
- update to version 0.32.0
  * If possible, Certbot uses built-in support for OCSP from recent
    cryptography versions instead of the OpenSSL binary: as a
    consequence Certbot does not need the OpenSSL binary to be
    installed anymore if cryptography>=2.5 is installed.
  * Certbot and its acme module now depend on josepy>=1.1.0.
  * Apache plugin now respects CERTBOT_DOCS environment variable when
    adding command line defaults.
  * The running of manual plugin hooks is now always included in
    Certbot's log output.
  * Tests execution now relies on pytest.
  * An ACME CA server may return a "Retry-After" HTTP header on
    authorization polling, as specified in the ACME protocol, to
    indicate when the next polling should occur. Certbot now reads
    this header if set and respect its value.
  * The acme module avoids sending the keyAuthorization field in
    the JWS payload when responding to a challenge as the field is
    not included in the current ACME protocol. To ease the migration
    path for ACME CA servers, Certbot and its acme module will first
    try the request without the keyAuthorization field but will
    temporarily retry the request with the field included if a
    malformed error is received. This fallback will be removed in
    version 0.34.0.
* Thu Mar 14 2019 Tomáš Chvátal <tchvatal@suse.com>
- Provide certbot namespace on py2 too to avoid migration conflict
* Fri Feb  8 2019 Marketa Calabkova <mcalabkova@suse.com>
- update to version 0.31.0
  * Avoid reprocessing challenges that are already validated when
    a certificate is issued.
  * Certbot's official Docker images are now based on Alpine Linux 3.9
    rather than 3.7.
  * Clarify behavior for deleting certs as part of revocation.
* Tue Jan 29 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.30.2:
  * Update the version of setuptools pinned in certbot-auto to 40.6.3 to
    solve installation problems on newer OSes.
  * Always download the pinned version of pip in pipstrap to address breakages
  * Rename old,default.conf to old-and-default.conf to address commas in filenames
    breaking recent versions of pip.
  * Add VIRTUALENV_NO_DOWNLOAD=1 to all calls to virtualenv to address breakages
    from venv downloading the latest pip
  * Added the `update_account` subcommand for account management commands.
* Sat Dec 15 2018 Thomas Bechtold <tbechtold@suse.com>
- update to 0.29.1:
  * The default work and log directories have been changed back
    to /var/lib/letsencrypt and /var/log/letsencrypt respectively.
  * Noninteractive renewals with `certbot renew` (those not started
    from a terminal) now randomly sleep 1-480 seconds before beginning
    work in order to spread out load spikes on the server side.
  * Added External Account Binding support in cli and acme library.
    Command line arguments --eab-kid and --eab-hmac-key added.
  * Private key permissioning changes: Renewal preserves existing group mode
    & gid of previous private key material. Private keys for new
    lineages (i.e. new certs, not renewed) default to 0o600.
  * Update code and dependencies to clean up Resource and Deprecation Warnings.
  * Only depend on imgconverter extension for Sphinx >= 1.6
- update URL
* Fri Nov 30 2018 Jason Craig <os-dev@jacraig.com>
- Add Requires: python-mock, it won't run without it
* Fri Nov 16 2018 Marketa Calabkova <mcalabkova@suse.com>
- update to version 0.28.0
  * revoke accepts --cert-name, and doesn't accept both --cert-name
    and --cert-path
* Tue Oct  9 2018 Tomáš Chvátal <tchvatal@suse.com>
- Do not conflict with Certbot as now we provide/obsolete it
* Wed Oct  3 2018 Tomáš Chvátal <tchvatal@suse.com>
- Provide and obsolete certbot main package too to ensure we can
  migrate to the new split setup directly
* Tue Sep 18 2018 Tomáš Chvátal <tchvatal@suse.com>
- Conflict with certbot package to allow easy migration
* Fri Sep 14 2018 Marketa Calabkova <mcalabkova@suse.com>
- update to version 0.27.1
  * the documentation can be built using Sphinx 1.6+
* Tue Aug 28 2018 tchvatal@suse.com
- Initial package, split from certbot blob
